@@ -5,19 +5,19 @@ use warnings;
 require Exporter ;
 use bytes;
 
-use IO::Compress::Base 2.072 ;
+use IO::Compress::Base 2.073 ;
 
-use IO::Compress::Base::Common  2.072 qw(isaScalar createSelfTiedObject);
-use IO::Compress::Adapter::LZO  2.072 ;
+use IO::Compress::Base::Common  2.073 qw(isaScalar createSelfTiedObject);
+use IO::Compress::Adapter::LZO  2.073 ;
 use Compress::LZO qw(crc32 adler32 LZO_VERSION);
-use IO::Compress::Lzop::Constants  2.072 ;
+use IO::Compress::Lzop::Constants  2.073 ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzopError);
 
-$VERSION = '2.072';
+$VERSION = '2.073';
 $LzopError = '';
 
-@ISA    = qw(Exporter IO::Compress::Base);
+@ISA    = qw( IO::Compress::Base Exporter );
 @EXPORT_OK = qw( $LzopError lzop ) ;
 %EXPORT_TAGS = %IO::Compress::Base::EXPORT_TAGS ;
 push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
